@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dancer2::Plugin::JWT;
 # ABSTRACT: JSON Web Token made simple for Dancer2
-$Dancer2::Plugin::JWT::VERSION = '0.007';
+$Dancer2::Plugin::JWT::VERSION = '0.008';
 use Dancer2::Plugin;
 use JSON::WebToken;
 use URI;
@@ -34,8 +34,8 @@ on_plugin_import {
         Dancer2::Core::Hook->new(
             name => 'before_template_render',
             code => sub {
-                my $tokens = shift;
-                $tokens->{jwt} = request->var('jwt');
+                my ($app, $tokens) = @_;
+                $tokens->{jwt} = $app->request->var('jwt');
             }
         )
     );
